extension OpenDatetimeExtensions on DateTime {
  static final DateTime _now = DateTime.now();

  String nowString() => _now.toUtc().toIso8601String();

  bool isToday() => _isSameDay(this, _now);

  bool isYesterday() =>
      _isSameDay(this, _now.subtract(const Duration(days: 1)));

  bool isTomorrow() => _isSameDay(this, _now.add(const Duration(days: 1)));

  bool isMorning() => hour >= 4 && hour < 12;
  bool isAfternoon() => hour >= 12 && hour < 18;
  bool isEvening() => hour < 4 || hour >= 18;

  String get timeOfDay {
    if (isMorning()) return 'morning';
    if (isAfternoon()) return 'afternoon';
    return 'evening';
  }

  DateTime get firstDateOfTheWeek => subtract(Duration(days: weekday - 1));

  DateTime get lastDateOfTheWeek =>
      add(Duration(days: DateTime.daysPerWeek - weekday));

  String formatSeconds(int value) {
    final hours = (value ~/ 3600).toString().padLeft(2, '0');
    final minutes = ((value % 3600) ~/ 60).toString().padLeft(2, '0');
    final seconds = (value % 60).toString().padLeft(2, '0');
    return "$hours:$minutes:$seconds";
  }

  String formatMinutes(int value, {bool allowZero = false}) {
    final hours = (value ~/ 60).toString().padLeft(2, '0');
    final minutes = (value % 60).toString().padLeft(2, '0');
    return minutes == '00' && !allowZero ? "$hours:01" : "$hours:$minutes";
  }

  DateTime get lastDayOfMonth =>
      (month < 12) ? DateTime(year, month + 1, 0) : DateTime(year + 1, 1, 0);

  static bool _isSameDay(DateTime date1, DateTime date2) {
    return date1.year == date2.year &&
        date1.month == date2.month &&
        date1.day == date2.day;
  }
}
