import 'dart:math';

import 'package:google_maps_flutter/google_maps_flutter.dart';

extension OpenGoogleMapsExtensions on GoogleMap {
  LatLngBounds getBoundsFromLatLngList(List<LatLng> list) {
    assert(list.isNotEmpty, 'The list cannot be empty');

    // Initialize bounds to the first point
    double x0 = list[0].latitude;
    double x1 = x0;
    double y0 = list[0].longitude;
    double y1 = y0;

    // Update bounds based on each point in the list
    for (var point in list.skip(1)) {
      x0 = min(x0, point.latitude);
      x1 = max(x1, point.latitude);
      y0 = min(y0, point.longitude);
      y1 = max(y1, point.longitude);
    }

    return LatLngBounds(northeast: LatLng(x1, y1), southwest: LatLng(x0, y0));
  }

  LatLng calculateCenter(List<LatLng> points) {
    assert(points.isNotEmpty, 'The points list cannot be empty.');

    final total = points.fold(
      const LatLng(0.0, 0.0),
      (LatLng acc, LatLng point) => LatLng(
          acc.latitude + point.latitude, acc.longitude + point.longitude),
    );

    return LatLng(
        total.latitude / points.length, total.longitude / points.length);
  }
}
