extension OpenStringExtension on String {
  String operator -(String rhs) => replaceAll(rhs, '');

  String truncateTo(int maxLength) =>
      (length <= maxLength) ? this : '${substring(0, maxLength - 3)}...';

  String shortenByWords(int maxLength) =>
      shortenByDelimiterWithCount(maxLength);

  String shortenByDelimiterWithCount(int maxLength, [String delimiter = ' ']) {
    if (length <= maxLength) return this;

    int endIndex = substring(0, maxLength).lastIndexOf(delimiter);
    if (endIndex == -1) return substring(0, maxLength);

    String shortened = substring(0, endIndex);
    int remainingWordsCount =
        split(delimiter).length - shortened.split(delimiter).length;
    return remainingWordsCount > 0
        ? '$shortened +$remainingWordsCount'
        : shortened;
  }

  Iterable<String> splitByLength(int len, {String filler = '0'}) sync* {
    String paddedString = padRight((length + len - 1) ~/ len * len, filler);
    for (var i = 0; i < paddedString.length; i += len) {
      yield paddedString.substring(i, i + len);
    }
  }

  String capitalize() =>
      length > 0 ? substring(0, 1).toUpperCase() + substring(1) : this;

  String decapitalize() =>
      length > 0 ? substring(0, 1).toLowerCase() + substring(1) : this;
}
